==> scim-bridge_0.2.3.orig.tar.gz: scim-bridge-0.2.3/agent/scim-bridge-agent-panel-listener-protected.h <==
/*
 * SCIM Bridge
 *
 * Copyright (c) 2006 Ryo Dairiki <ryo-dairiki@users.sourceforge.net>
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.*
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU Lesser General Public License for more details.*
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#ifndef SCIMBRIDGEAGENTPANELLISTENERPROTECTED_H_
#define SCIMBRIDGEAGENTPANELLISTENERPROTECTED_H_

#define Uses_SCIM_PANEL_CLIENT

#include <scim.h>

#include <vector>

#include "scim-bridge-imcontext.h"

class ScimBridgeAgentPanelListenerProtected
{

    public:

        virtual ~ScimBridgeAgentPanelListenerProtected ();

        virtual void focus_in (const scim::String &factory_uuid) = 0;
        virtual void focus_out () = 0;

        virtual void update_screen () = 0;
        virtual void update_cursor_location (int x, int y) = 0;
        virtual void update_factory_info (const scim::PanelFactoryInfo &factory_info) = 0;

        virtual void turn_on () = 0;
        virtual void turn_off () = 0;

        virtual void set_aux_string (const scim::WideString &str, const scim::AttributeList &attrs) = 0;
        virtual void show_aux_string () = 0;
        virtual void hide_aux_string () = 0;

        virtual void set_lookup_table (const scim::LookupTable &table) = 0;
        virtual void show_lookup_table () = 0;
        virtual void hide_lookup_table () = 0;

        virtual void set_preedit_cursor_position (int cursor_pos) = 0;
        virtual void set_preedit_string (const scim::WideString &str, const scim::AttributeList &attrs) = 0;
        virtual void show_preedit () = 0;
        virtual void hide_preedit () = 0;

        virtual void start_helper (const scim::String &helper_uuid) = 0;
        virtual void stop_helper (const scim::String &helper_uuid) = 0;
        virtual void send_helper_event (const scim::String &helper_uuid, const scim::Transaction &trans) = 0;

        virtual void register_properties (const scim::PropertyList &properties) = 0;
        virtual void update_property (const scim::Property &property) = 0;

        virtual void show_factory_menu (const std::vector<scim::PanelFactoryInfo> &menu) = 0;
        virtual void show_help (const scim::String &string) = 0;

        virtual void register_input_context (scim_bridge_imcontext_id_t id, const scim::String &factory_uuid) = 0;
        virtual void remove_input_context (scim_bridge_imcontext_id_t id) = 0;

    protected:

        ScimBridgeAgentPanelListenerProtected ();

};
#endif                                            /*SCIMBRIDGEAGENTPANELLISTENERPROTECTED_H_*/

==> scim-bridge-0.2.7.tar.gz: scim-bridge-0.2.7/agent/scim-bridge-agent-panel-listener-protected.h <==
/*
 * SCIM Bridge
 *
 * Copyright (c) 2006 Ryo Dairiki <ryo-dairiki@users.sourceforge.net>
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.*
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU Lesser General Public License for more details.*
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#ifndef SCIMBRIDGEAGENTPANELLISTENERPROTECTED_H_
#define SCIMBRIDGEAGENTPANELLISTENERPROTECTED_H_

#define Uses_SCIM_PANEL_CLIENT

#include <scim.h>

#include <vector>

#include "scim-bridge-imcontext.h"

class ScimBridgeAgentPanelListenerProtected
{

    public:

        virtual ~ScimBridgeAgentPanelListenerProtected ();

        virtual void focus_in (const scim::String &factory_uuid) = 0;
        virtual void focus_out () = 0;

        virtual void update_screen () = 0;
        virtual void update_cursor_location (int x, int y) = 0;
        virtual void update_factory_info (const scim::PanelFactoryInfo &factory_info) = 0;

        virtual void turn_on () = 0;
        virtual void turn_off () = 0;

        virtual void set_aux_string (const scim::WideString &str, const scim::AttributeList &attrs) = 0;
        virtual void show_aux_string () = 0;
        virtual void hide_aux_string () = 0;

        virtual void set_lookup_table (const scim::LookupTable &table) = 0;
        virtual void show_lookup_table () = 0;
        virtual void hide_lookup_table () = 0;

        virtual void set_preedit_cursor_position (int cursor_pos) = 0;
        virtual void set_preedit_string (const scim::WideString &str, const scim::AttributeList &attrs) = 0;
        virtual void show_preedit () = 0;
        virtual void hide_preedit () = 0;

        virtual void start_helper (const scim::String &helper_uuid) = 0;
        virtual void stop_helper (const scim::String &helper_uuid) = 0;
        virtual void send_helper_event (const scim::String &helper_uuid, const scim::Transaction &trans) = 0;

        virtual void register_properties (const scim::PropertyList &properties) = 0;
        virtual void update_property (const scim::Property &property) = 0;

        virtual void show_factory_menu (const std::vector<scim::PanelFactoryInfo> &menu) = 0;
        virtual void show_help (const scim::String &string) = 0;

        virtual void register_input_context (const scim::String &factory_uuid) = 0;
        virtual void remove_input_context () = 0;

    protected:

        ScimBridgeAgentPanelListenerProtected ();

};
#endif                                            /*SCIMBRIDGEAGENTPANELLISTENERPROTECTED_H_*/
